#
# spec file for package python-scikit-image
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define skip_python2 1
Name:           python-scikit-image
Version:        0.16.2
Release:        bp155.3.15
Summary:        Collection of algorithms for image processing in Python
License:        BSD-3-Clause
URL:            https://scikit-image.org/
Source0:        https://files.pythonhosted.org/packages/source/s/scikit-image/scikit-image-%{version}.tar.gz
BuildRequires:  %{python_module Cython >= 0.23.4}
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module numpy-devel >= 1.11}
BuildRequires:  %{python_module scipy >= 0.17}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module six >= 1.7.3}
BuildRequires:  fdupes
BuildRequires:  freeimage-devel
BuildRequires:  gcc-c++
BuildRequires:  python-rpm-macros
Requires:       python-Pillow >= 2.1.0
Requires:       python-PyWavelets >= 0.4.0
Requires:       python-matplotlib >= 1.3.1
Requires:       python-networkx >= 1.8
Requires:       python-numpy >= 1.11
Requires:       python-scipy >= 0.17
Requires:       python-six >= 1.7.3
Requires(post): update-alternatives
Requires(preun): update-alternatives
Recommends:     python-SimpleITK
Recommends:     python-astropy
Recommends:     python-dask-array >= 0.5.0
Recommends:     python-imread
Recommends:     python-pyamg
Recommends:     python-qt4
# SECTION test requirements
BuildRequires:  %{python_module Pillow >= 2.1.0}
BuildRequires:  %{python_module PyWavelets >= 0.4.0}
BuildRequires:  %{python_module imageio}
BuildRequires:  %{python_module matplotlib >= 1.3.1}
BuildRequires:  %{python_module networkx >= 1.8}
BuildRequires:  %{python_module pytest >= 4.0}
BuildRequires:  %{python_module pytest-localserver}
BuildRequires:  %{python_module pytest-xdist}
# /SECTION
%python_subpackages

%description
Scikit-image is a collection of algorithms for image processing in Python.
It is available free of charge and free of restriction.

%prep
%setup -q -n scikit-image-%{version}
%autopatch -p1

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%python_clone -a %{buildroot}%{_bindir}/skivi

%post
%python_install_alternative skivi

%preun
%python_uninstall_alternative skivi

%check
export PYTHONDONTWRITEBYTECODE=1 # do not write unreproducible test_random_walker.cpython-37-PYTEST.pyc files (boo#1062303)
mv skimage skimage_temp
# test_wrap_around - fails randomly https://github.com/scikit-image/scikit-image/issues/3237
# test_structural_similarity_dtype - also fails randomly on 32bit
%pytest_arch -v %{buildroot}%{$python_sitearch}/skimage -n auto -k 'not (test_wrap_around or test_structural_similarity_dtype or test_imageio_truncated_jpg)'
mv skimage_temp skimage

%files %{python_files}
%license LICENSE.txt
%doc CONTRIBUTORS.txt TODO.txt
%python_alternative %{_bindir}/skivi
%{python_sitearch}/skimage/
%{python_sitearch}/scikit_image-%{version}-py*.egg-info

%changelog
* Tue May 10 2022 Max Lin <mlin@suse.com>
- Skip test_imageio_truncated_jpg test
* Tue May 12 2020 Tomáš Chvátal <tchvatal@suse.com>
- We need at least pytest 4.x series
* Fri Jan 17 2020 Tomáš Chvátal <tchvatal@suse.com>
- Skip 2 failing tests on 32bit
- Do not buildrequire nose
* Wed Dec  4 2019 Tomáš Chvátal <tchvatal@suse.com>
- Use xdist to speed up the testing that takes bit too much time
* Sat Nov  9 2019 Arun Persaud <arun@gmx.de>
- specfile:
  * remove two patched (included upstream):
  - fix_numpy_1_17.patch
  - fix_numpy_matrix_warning_test.patch
  * add test requirement imageio
- update to version 0.16.2 (bsc#1157707):
  * Bug fixes
    + Migrate to networkx 2.x (#4236, #4237)
    + Sync required numpy and dask to runtime versions (#4233, #4239)
    + Fix wrong argument parsing in structural_similarity (#4246,
    [#4247])
    + Fix active contour gallery example after change to rc
    coordinates (#4257, #4262)
- changes from version 0.16.1:
  * New Features
    + New `skimage.evaluate` module containing simple metrics (mse,
    nrme, psd) and segmentation metrics (adapted rand error,
    variation of information) (#4025)
    + n-dimensional TV-L1 optical flow algorithm for registration --
    `skimage.registration.optical_flow_tvl1` (#3983)
    + Draw a line in an n-dimensional array -- `skimage.draw.line_nd`
    (#2043)
    + 2D Farid & Simoncelli edge filters - `skimage.filters.farid`,
    `skimage.filters.farid_h`, and `skimage.filters.farid_v` (#3775)
    + 2D majority voting filter assigning to each pixel the most
    commonly occurring value within its neighborhood --
    `skimage.filters.majority` (#3836, #3839)
    + Multi-level threshold "multi-Otsu" method, a thresholding
    algorithm used to separate the pixels of an input image into
    several classes by maximizing the variances between classes --
    `skimage.filters.threshold_multiotsu` (#3872, #4174)
    + New example data -- `skimage.data.shepp_logan_phantom`,
    `skimage.data.colorwheel`, `skimage.data.brick`,
    `skimage.data.grass`, `skimage.data.roughwall`,
    `skimage.data.cell` (#3958, #3966)
    + Compute and format image region properties as a table
  - -.measure.regionprops_table` (#3959)
    + Convert a polygon into a mask -- `skimage.draw.poly2mask`
    (#3971, #3977)
    + Visual image comparison helper `skimage.util.compare_images`,
    that returns an image showing the difference between two input
    images (#4089)
    + `skimage.transform.warp_polar` to remap image into polar or
    log-polar coordinates. (#4097)
  * Improvements
    + RANSAC: new option to set initial samples selected for
    initialization (#2992)
    + Better repr and str for `skimage.transform.ProjectiveTransform`
    (#3525, #3967)
    + Better error messages and data type stability to
    `skimage.segmentation.relabel_sequential` (#3740)
    + Improved compatibility with dask arrays in some image
    thresholding methods (#3823)
    + `skimage.io.ImageCollection` can now receive lists of patterns
    (#3928)
    + Speed up `skimage.feature.peak_local_max` (#3984)
    + Better error message when incorrect value for keyword argument
    `kind` in.color.label2rgb` (#4055)
    + All functions from `skimage.drawing` now supports multi-channel
    2D images (#4134)
  * API Changes
    + Deprecated subpackage "skimage.novice" has been removed.
    + Default value of "multichannel" parameters has been set to False
    in `skimage.transform.rescale`,
    `skimage.transform.pyramid_reduce`,
    `skimage.transform.pyramid_laplacian`,.transform.pyramid_gaussian`,
    and `skimage.transform.pyramid_expand`. Guessing is no longer
    performed for 3D.
    + Deprecated argument "visualise" has been removed
    from.feature.hog`. Use "visualize" instead.¨
    + `skimage.transform.seam_carve` has been completely removed from
    the library due to licensing restrictions.
    + Parameter "as_grey" has been removed from `skimage.data.load`
    and `skimage.io.imread`. Use "as_gray" instead.
    + Parameter "min_size" has been removed from
    `skimage.morphology.remove_small_holes`. Use "area_threshold"
    instead.
    + Deprecated "correct_mesh_orientation" in `skimage.measure` has
    been removed.
    + `skimage.measure._regionprops` has been completely switched to
    using-column coordinates. Old x-y interface is not longer
    available.
    + Default value of "behavior" parameter has been set to "ndimage"
    in `skimage.filters.median`.
    + Parameter "flatten" in `skimage.io.imread` has been removed in
    favor of "as_gray".
    + Parameters "Hxx, Hxy, Hyy" have been removed from
    `skimage.feature.corner.hessian_matrix_eigvals` in favor of
    "H_elems".
    + Default value of "order" parameter has been set to "rc" in
    `skimage.feature.hessian_matrix`.
    + "skimage.util.img_as_*" functions no longer raise precision
    and/or loss warnings.
  * Bugfixes
    + Corrected error with scales attribute in ORB.detect_and_extract
    (#2835) The scales attribute wasn't taking into account the
    mask, and thus was using an incorrect array size.
    + Correct for bias in Inverse Randon Transform
    (`skimage.transform.irandon`) (#3067) Fixed by using the Ramp
    filter equation in the spatial domain as described in the
    reference
    + Fix a rounding issue that caused a rotated image to have a
    different size than the input (`skimage.transform.rotate`)
    (#3173)
    + RANSAC uses random subsets of the original data and not
    bootstraps. (#3901, #3915)
    + Canny now produces the same output regardless of dtype (#3919)
    + Geometry Transforms: avoid division by zero & some degenerate
    cases (#3926)
    + Fixed float32 support in denoise_bilateral and
    denoise_tv_bregman (#3936)
    + Fixed computation of Meijering filter and avoid
    ZeroDivisionError (#3957)
    + Fixed `skimage.filters.threshold_li` to prevent being stuck on
    stationnary points, and thus at local minima or maxima (#3966)
    + Edited `skimage.exposure.rescale_intensity` to return input
    image instead of nans when all 0 (#4015)
    + Fixed `skimage.morphology.medial_axis`. A wrong indentation in
    Cython caused the function to not behave as intended. (#4060)
    + Fixed `skimage.restoration.denoise_bilateral` by correcting the
    padding in the gaussian filter(#4080)
    + Fixed `skimage.measure.find_contours` when input image contains
    NaN.  Contours interesting NaN will be left open (#4150)
    + Fixed `skimage.feature.blob_log` and `skimage.feature.blob_dog`
    for 3D images and anisotropic data (#4162)
    + Fixed `skimage.exposure.adjust_gamma`,
    `skimage.exposure.adjust_log`, and
    `skimage.exposure.adjust_sigmoid` such that when provided with a
    1 by 1 ndarray, it returns 1 by 1 ndarrays and not single number
    floats (#4169)
  * Deprecations
    + Parameter "neighbors" in `skimage.measure.convex_hull_object`
    has been deprecated in favor of "connectivity" and will be
    removed in version 0.18.0.
    + The following functions are deprecated in favor of the
    `skimage.metrics` module (#4025):
  - `skimage.measure.compare_mse`
  - `skimage.measure.compare_nrmse`
  - `skimage.measure.compare_psnr`
  - `skimage.measure.compare_ssim`
    + The function `skimage.color.guess_spatial_dimensions` is
    deprecated and will be removed in 0.18 (#4031)
    + The argument "bc" in `skimage.segmentation.active_contour` is
    deprecated.
    + The function `skimage.data.load` is deprecated and will be
    removed in 0.18 (#4061)
    + The function `skimage.transform.match_histogram` is deprecated
    in favor of `skimage.exposure.match_histogram` (#4107)
    + The parameter "neighbors" of
    `skimage.morphology.convex_hull_object` is deprecated.
    + The `skimage.transform.randon_tranform` function will convert
    input image of integer type to float by default in 0.18. To
    preserve current behaviour, set the new argument
    "preserve_range" to True. (#4131)
  * For further documentation improvements and misc pull request see
    https://github.com/scikit-image/scikit-image/blob/v0.16.x/doc/release/release_0.16.rst
* Wed Jul 31 2019 Todd R <toddrme2178@gmail.com>
- Add fix_numpy_1_17.patch
  Fixes building with numpy 1.17
  From gh#scikit-image/scikit-image#3992
* Sat Jul 27 2019 Bernhard Wiedemann <bwiedemann@suse.com>
- do not write unreproducible test_random_walker.cpython-37-PYTEST.pyc
  files (boo#1062303)
* Tue Jul 23 2019 Todd R <toddrme2178@gmail.com>
  + New Features
  * N-dimensional flood fill, with tolerance
  * Attribute operators
  * Extension of register_translation to enable subpixel precision in 3D and
    optionally disable error calculation
  * unsharp mask filtering
  * New options ``connectivity``, ``indices`` and ``allow_borders`` for
    ``skimage.morphology.local_maxima`` and ``local_minima``.
  * Image translation registration for masked data
    (``skimage.feature.masked_register_translation``)
  * Frangi (vesselness), Meijering (neuriteness), and Sato (tubeness) filters
  * Allow float->float conversion of any range
  * Let lower precision float arrays pass through ``img_as_float``
  * Lazy apply_parallel (allows optimization of dask array operations)
  * Add range option for histogram.
  * Add histogram matching
  + Improvements
  * Replace ``morphology.local_maxima`` with faster flood-fill based Cython
    version
  * ``skivi`` is now using ``qtpy`` for Qt4/Qt5/PySide/PySide2 compatibility (a
    new optional dependency).
  * Performance is now monitored by
    `Airspeed Velocity <https://asv.readthedocs.io/en/stable/>`_. Benchmark
    results will appear at https://pandas.pydata.org/speed/
  * Speed up inner loop of GLCM
  * Allow tuple to define kernel in threshold_niblack and threshold_sauvola
  * Add support for anisotropic blob detection in blob_log and blob_dog
  + API Changes
  * ``skimage.transform.seam_carve`` has been removed because the algorithm is
    patented.
  * Parameter ``dynamic_range`` in ``skimage.measure.compare_psnr`` has been
    removed. Use parameter ``data_range`` instead.
  * imageio is now the preferred plugin for reading and writing images.
  * imageio is now a dependency of scikit-image.
  * ``regular_grid`` now returns a tuple instead of a list for compatibility
    with numpy 1.15
  * ``colorconv.separate_stains`` and ``colorconv.combine_stains`` now uses
    base10 instead of the natural logarithm as discussed in issue #2995.
  * Default value of ``clip_negative`` parameter in ``skimage.util.dtype_limits``
    has been set to ``False``.
  * Default value of ``circle`` parameter in ``skimage.transform.radon``
    has been set to ``True``.
  * Default value of ``circle`` parameter in ``skimage.transform.iradon``
    has been set to ``True``.
  * Default value of ``mode`` parameter in ``skimage.transform.swirl``
    has been set to ``reflect``.
  * Deprecated ``skimage.filters.threshold_adaptive`` has been removed.
    Use ``skimage.filters.threshold_local`` instead.
  * Default value of ``multichannel`` parameter in
    ``skimage.restoration.denoise_bilateral`` has been set to ``False``.
  * Default value of ``multichannel`` parameter in
    ``skimage.restoration.denoise_nl_means`` has been set to ``False``.
  * Default value of ``mode`` parameter in ``skimage.transform.resize``
    and ``skimage.transform.rescale`` has been set to ``reflect``.
  * Default value of ``anti_aliasing`` parameter in ``skimage.transform.resize``
    and ``skimage.transform.rescale`` has been set to ``True``.
  * Removed the ``skimage.test`` function. This functionality can be achieved
    by calling ``pytest`` directly.
  * ``morphology.local_maxima`` now returns a boolean array
  + Bugfixes
  * Correct bright ridge detection for Frangi filter
  * ``skimage.morphology.local_maxima`` and ``skimage.morphology.local_minima``
    no longer raise an error if any dimension of the image is smaller 3 and
    the keyword ``allow_borders`` was false.
  * ``skimage.morphology.local_maxima`` and ``skimage.morphology.local_minima``
    will return a boolean array instead of an array of 0s and 1s if the
    parameter ``indices`` was false.
  * When ``compare_ssim`` is used with ``gaussian_weights`` set to True, the
    boundary crop used when computing the mean structural similarity will now
    exactly match the width of the Gaussian used. The Gaussian filter window is
    also now truncated at 3.5 rather than 4.0 standard deviations to exactly match
    the original publication on the SSIM. These changes should produce only a very
    small change in the computed SSIM value. There is no change to the existing
    behavior when ``gaussian_weights`` is False.
  * erroneous use of cython wrap around
  * Speed up block reduce by providing the appropriate parameters to numpy
  * Add urllib.request again
  * Repeat pixels in reflect mode when image has dimension 1
  * Improve Li thresholding
  + Deprecations
  * Python 2 support has been dropped. Users should have Python >= 3.5.
  * ``skimage.util.montage2d`` has been removed. Use ``skimage.util.montage`` instead.
  * ``skimage.novice`` is deprecated and will be removed in 0.16.
  * ``skimage.transform.resize`` and ``skimage.transform.rescale`` option
    ``anti_aliasing`` has been enabled by default.
  * ``regionprops`` will use row-column coordinates in 0.16. You can start
    using them now with ``regionprops(..., coordinates='rc')``. You can silence
    warning messages, and retain the old behavior, with
    ``regionprops(..., coordinates='xy')``. However, that option will go away
    in 0.16 and result in an error. This change has a number of consequences.
    Specifically, the "orientation" region property will measure the
    anticlockwise angle from a *vertical* line, i.e. from the vector (1, 0) in
    row-column coordinates.
  * ``skimage.morphology.remove_small_holes`` ``min_size`` argument is deprecated
    and will be removed in 0.16. Use ``area_threshold`` instead.
  * ``skimage.filters.median`` will change behavior in the future to have an
    identical behavior as ``scipy.ndimage.median_filter``. This behavior can be
    set already using ``behavior='ndimage'``. In 0.16, it will be the default
    behavior and removed in 0.17 as well as the parameter of the previous
    behavior (i.e., ``mask``, ``shift_x``, ``shift_y``) will be removed.
  + Documentation improvements
  * Correct rotate method's center parameter doc
  * Add Sphinx copybutton
  * Add glossary to the documentation
  * Add image of retina to our data
  * Add microaneurysms() to gallery
  * Better document remove_small_objects behaviour: int vs bool
  * Linking preserve_range parameter calls to docs
  * Update the documentation regarding datalocality
  * Specify conda-forge channel for scikit-image conda install
  * Turn DOIs into web links in docstrings
  * Update documentation for regionprops
  * DOC: Improve the RANSAC gallery example
  * DOC: "feature.peak_local_max" : explanation of multiple same-intensity peaks returned by the function; added details on ``exclude_border`` parameter
  + Improvements
  * MNT: handle a deprecation warning for np.linspace and floats for the num parameter
  * TST: numpy empty arrays are not inherently Falsy
  * handle warning in scipy cdist for unused parameters
  * MNT: don't use filter_warnings in test suite.
  * Add doc notes on setting up the build environment
  * Release the GIL in numerous cython functions
  * Cython touchups to use float32 and float64
  * rank_filters: Change how the bitdepth and max_bin are computed to ensure exact warnings.
  * Rank: Optimize OTSU filter
  * Rank - Fix rank entropy and OTSU tests
  * delay importing pyplot in manual segmentation
  * Get rid of the requirements-parser dependency
  * filter warning from ``correct_mesh_orientation`` in tests
  * cloudpickle is really a doc dependency, not a core one
  * optional dependencies on pip
  * Fewer test warnings in 3.7
  * collections.abc nit
  * Streamlined issue template
  * Tighten the PR Template
  * Use language level to 3 in cython for future compatibility
  * Update ISSUE_TEMPLATE.md with info about numpy and skimage versions
  * Use relative imports for many cython modules
  * Pass tests that don't raise floating point exceptions on arm with soft-fp
  + Other improvements
  * BUG: Fix greycoprops correlation always returning 1
  * Add section on API discovery via ``skimage.lookfor``
  * Speedup 2D warping for affine transformations
  * Credit Reviewers in Release Notes
  * Added small galleries in the API
  * Use skimage gaussian filter to avoid integer rounding artifacts
  * Remove Python 2 compatibility
  * Add ``rectangle_perimeter`` feature to ``skimage.draw``
  * Update installation instructions to reference existing requirements specification
  * Updated release notes with pre 0.13.1 phase
  * Release guidelines update
  * Ensure we are installing with / running on Python 3
  * Hide warnings in test_unsharp_mask
  * Process 0.15 deprecations
  * Documentation: always use dev branch javascript
  * Add initial airspeed velocity (asv) framework
  * Supress warnings for flatten during io testing
  * Recover from exceptions in filters.try_all_threshold()
  * Fix skimage.test() to run the unittests
  * skivi: Use qtpy to handle different Qt versions
  * Refactor python version checking.
  * Move data_dir to within ``data/__init__.py``
  * Move the definition of lookfor out of __init__.py
  * Normalize the package number to PEP440
  * Remove skimage.test as it was never used.
  * Added a message about qtpy to the INSTALL.rst
  * Regression fix: Travis should fail if tests fail
  * Set minimum cython version to ``0.23.4``
  * Add rgba2rgb to API docs
  * Minor doc formatting fixes in video.rst
  * Decrease the verbosity of the testing
  * Speedup rgb2gray using matrix multiply
  * Add instructions for meeseeksdev to PR template
  * Remove installation instructions for video packages
  * Big image labeling fix
  * Handle dask deprecation in cycle_spin
  * Fix Qt viewer painttool indexing
  * build_versions.py is no longer hard coded.
  * Remove dtype constructor call in exposure.rescale_intensity
  * Various updates to the ASV benchmarks
  * Add a link to stack overflow on github README
  * MAINT: remove encoding information in file headers (python 3)
  * Build tools: Dedicate a --pre build in appveyor and ensure other builds don't download --pre
  * Fix the human readable error message on a bad build.
  * Respect input array type in apply_parallel by default
  * Travis cleanup pip commands
  * Add benchmarks for morphology.watershed
  * Correcte docstring formatting so that code block is displayed as code
  * Defer skimage.io import of matplotlib.pyplot until needed
  * Add benchmark for Sobel filters
  * Remove cython md5 hashing since it breaks the build process
  * Fix typo in documentation.
  * Issue 3156: skimage/__init__.py Update docstring and fix import *
  * Object detector module
  * Do not import submodules while building
  * Add benchmark suite for canny
  * improve segmentation.felzenszwalb document #3264
  * Update _canny.py
  * Add benchmark suite for histogram equalization
  * fix link to equalist_hist blog reference
  * .gitignore: novice: Ignore save-demo.jpg
  * Guide the user of denoise_wavelet to choose an orthogonal wavelet.
  * Remove unused lib in skimage/__init__.py
  * BUILD: Add pyproject.toml to ensure cython is present
  * Handle intersphinx and mpl deprecation warnings in docs
  * Minor PEP8 fixes
  * cython: check for presence of cpp files during install from sdist
  * appveyor: don't upload any artifacts
  * Add benchmark suite for hough_line()
  * Novice skip url test
  * Remove benchmarks from wheel
  * Add license file to the wheel (binary) distribution
  * codecov: ignore build scripts in coverage and don't comment on PRs
  * Matplotlib 2.2.3 +  PyQt5.11
  * Allow @hmaarrfk to mention MeeseeksDev to backport.
  * Add Python 3.7 to the test matrix
  * Fix deprecated keyword from dask
  * Incompatible modes with anti-aliasing in skimage.transform.resize
  * Missing cval parameter in threshold_local
  * Avoid Sphinx 1.7.8
  * Show our data in the gallery
  * Minor updates to grammar in numpy images page
  * assert_all_close doesn't exist, make it ``assert_array_equal``
  * Better behavior of Gaussian filter for arrays with a large number of dimensions
  * Allow import/execution with -OO
  * Mark tests known to fail on 32bit architectures with xfail
  * Hardcode the inputs to test_ssim_grad
  * TST: make test_wavelet_denoising_levels compatible with PyWavelets 1.0
  * Allow tifffile.py to handle I/O.
  * Add explicit Trove classifier for Python 3
  * Fix error in contribs.py
  * MAINT: remove pyside restriction since we don't support Python 3.4 anymore
  * Build tools: simplify how MPL_DIR is obtained.
  * Build tools: Don't run tests twice in travis.
  * Build tools: Add an OSX build with optional dependencies.
  * MAINT: Reverted the changes in #3300 that broke the MINIMIUM_REQUIREMENTS tests
  * MNT: Convert links using http to https
  * MAINT: Use upstream colormaps now that matplotlib has been upgraded
  * Build tools: Make pyamg an optional dependency and remove custom logic
  * Build tools: Fix PyQt installed in minimum requirements build
  * MNT: multiprocessing should always be available since we depend on python >=2.7
  * MAINT Use np.full instead of cst*np.ones
  * DOC: Fix LaTeX build via ``make latexpdf``
  * Update instructions et al for releases after 0.14.1
  * Remove code specific to python 2
  * Fix default value of ``methods`` in ``_try_all`` to avoid exception
  * Fix morphology.local_maxima for input with any dimension < 3
  * Use raw strings to avoid unknown escape symbol warnings
  * Speed up xyz2rgb by clipping output in place
  * MNT; handle deprecation warnings in tifffile
  * Build tools: TST: filter away novice deprecation warnings during testing
  * Build tools: don't use the pytest.fixtures decorator anymore in class fixtures
  * Preserving the fill_value of a masked array
  * Fix VisibleDeprecationWarning from np.histogram, normed=True
  * Build Tools: DOC: Document that now PYTHONOPTMIZE build is blocked by SciPy
  * DOC: Replace broken links by webarchive equivalent links
  * FIX: making the plot_marching_cubes example visible.
  * Avoid Travis failure regarding ``skimage.lookfor``
  * Fix Python executable for sphinx-build in docs Makefile
  * Build Tools: Blacklist specific Cython versions
  * Fix typos
  * Add "optional" indications to docstrings
  * Rename 'mnxc' (masked normalize cross-correlation) to something more descriptive
  * Random walker bug fix: no error should be raised when there is nothing to do
  * Various minor edits for active contour
  * Fix range for uint32 dtype in user guide
  * Raise meaningful exception in warping when image is empty
  * DOC: Development installation instructions for Ubuntu are missing tkinter
  * Better gallery examples and tests for masked translation registration
  * DOC: make more docstrings compliant with our standards
  * Build tools: Remove restriction on simpleitk for python 3.7
  * Speedup and add benchmark for ``skeletonize_3d``
  * Update requirements/README.md on justification of matplotlib 3.0.0 in favor of #3476
  * Doc enhancements around denoising features.
  * Use 'getconf _NPROCESSORS_ONLN' as fallback for nproc in Makefile of docs
  * Fix matplotlib set_*lim API deprecations
  * Switched from np.power to np.cbrt
  * Filtered out DeprecationPendingWarning for matrix subclass
  * Add RGB to grayscale example to gallery
  * Build tools: Refactor check_sdist so that it takes a filename as a parameter
  * Turn dask to an optional requirement
  * _marching_cubes_lewiner_cy: mark char as signed
  * Hyperlink DOIs to preferred resolver
  * Missing parameter description in ``morphology.reconstruction`` docstring #3581
  * Update chat location
  * Remove orphan code (skimage/filters/_ctmf.pyx).
  * More explicit example title, better list rendering in plot_cycle_spinning.py
  * Add rgb to hsv example in the gallery
  * Update documentation of ``perimeter`` and add input validation
  * Additionnal mask option to clear_border
  * Set up CI with Azure Pipelines
  * [MRG] EHN: median filters will accept floating image
  * Update Travis-CI to xcode 10.1
  * Minor tweaks to _mean_std code
  * Add explicit ordering of gallery sections
  * Delete broken links
  * Build tools: Fix test_mpl_imshow for matplotlib 2.2.3 and numpy 1.16
  * First draft of core dev guide
  * Add more details about the home page build process
  * Ensure images resources with long querystrings can be read
  * Delay matplotlib import in skimage/future/manual_segmentation.py
  * make the low contrast check optional when saving images
  * Correctly ignore release notes auto-generated for docs
  * Remove MANIFEST file when making the 'clean' target
  * Clarify return values in _overlap docstrings in feature/blob.py
  * Contribution script: allow specification of GitHub development branch
  * Update core dev guide: deprecation, contributor guide, required experience
  * Add release notes for 0.14.2
  * FIX gallery: Add multichannel=True to match_histogram
  * MAINT Minor code style improvements
  * Pass parameters through tifffile plugin
  * DOC unusused im3d_t in example
  * Remove wrong cast of Py_ssize_t to int
  * Build tools: allow python 3.7 to fail, but travis to continue
  * Build tools: remove pyproject.toml
  * Fix ValueError: not enough values to unpack
  * Several fixes for heap.pyx
  * Enable the faulthandler module during testing
  * Build tools: Fix Python 3.7 builds on travis
  * Replace np.einsum with np.tensordot in _upsampled_dft
  * Fix potential use of NULL pointers
  * Fix potential memory leak
  * Fix potential use of NULL pointers
  * Fix and improve core_cy.pyx
  * Build tools: Downgrade Xcode to 9.4 on master
  * Improve visual_test.py
  * Updated painttool to work with color images and properly scale labels.
  * Add image.sc forum badge to README
  * Blacklist PyQt 5.12.0 on Travis
  * Build tools: Fix matplotlib + qt 5.12 the same way upstream does it
  * gallery: remove xx or yy  sorted directory names
  * Allow for f-contiguous 2D arrays in convex_hull_image
  * Build tools: Set astropy minimum requirement to 1.2 to help the CIs.
  * Avoid NumPy warning while stacking arrays.
  * Set CC0 for microaneurysms
  * Unify LICENSE files for easier interpretation
  * Readme: Remove expectation for future fix from matplotlib
  * Improved documentation/test in ``flood()``
  * Use ssize_t in denoise cython
  * Removed non-existent parameter in docstring
  * Remove redundant point in draw.polygon docstring example
  * Ensure watershed auto-markers respect mask
- Add fix_numpy_matrix_warning_test.patch
  to fixup the test for the warnings for scipy 1.3 and the
  matrix subsclass. From gh#scikit-image/scikit-image#3869
* Sun Jan 20 2019 Arun Persaud <arun@gmx.de>
- specfile:
  * update copyright year
- update to version 0.14.2:
  * API changes
    + "skimage.measure.regionprops" no longer removes singleton
    dimensions from label images (#3284). To recover the old
    behavior, replace "regionprops(label_image)" calls with
    "regionprops(np.squeeze(label_image))"
  * Bug fixes
    + Address deprecation of NumPy "_validate_lengths" (backport of
    [#3556])
    + Correctly handle the maximum number of lines in Hough transforms
    (backport of #3514)
    + Correctly implement early stopping criterion for rank kernel
    noise filter (backport of #3503)
    + Fix "skimage.measure.regionprops" for 1x1 inputs (backport of
    [#3284])
  * Enhancements
    + Rewrite of "local_maxima" with flood-fill (backport of #3022,
    [#3447])
  * Build Process & Testing
    + Dedicate a "--pre" build in appveyor (backport of #3222)
    + Avoid Travis-CI failure regarding "skimage.lookfor" (backport of
    [#3477])
    + Stop using the "pytest.fixtures" decorator (#3558)
    + Filter out DeprecationPendingWarning for matrix subclass (#3637)
    + Fix matplotlib test warnings and circular import (#3632)
* Mon Oct  8 2018 Arun Persaud <arun@gmx.de>
- specfile:
  * increase Cython requirement to 0.23.4
- update to version 0.14.1:
  * Bug fixes
    + skimage.color.adapt_rgb was applying input functions to the
    wrong axis (#3097)
    + CollectionViewer now indexes correctly (it had been broken by an
    update to NumPy indexing) (#3288)
    + Handle deprecated indexing-by-list and NumPy matrix from NumPy
    1.15 (#3238, #3242, #3292)
    + Fix incorrect inertia tensor calculation (#3303) (Special thanks
    to JP Cornil for reporting this bug and for their patient help
    with this fix)
    + Fix missing comma in __all__ listing of moments_coord_central,
    so it and moments_normalized can now be correctly imported from
    the measure namespace (#3374)
    + Fix background color in label2rgb(..., kind='avg') (#3280)
  * Enhancements
    + "Reflect" mode in transforms now works fine when an image
    dimension has size 1 (#3174)
    + img_as_float now allows single-precision (32-bit) float arrays
    to pass through unmodified, rather than being up-converted to
    64-bit (#3110, #3052, #3391)
    + Speed up rgb2gray computation (#3187)
    + The scikit-image viewer now works with different PyQt versions
    (#3157)
    + The cycle_spin function for enhanced denoising works
    single-threaded when dask is not installed now (#3218)
    + scikit-image's io module will no longer inadvertently set the
    matplotlib backend when imported (#3243)
    + Fix deprecated get keyword from dask in favor of scheduler
    (#3366)
    + Add missing cval parameter to threshold_local (#3370)
  * API changes
    + Remove deprecated dynamic_range in measure.compare_psnr (#3313)
  * Documentation
    + Improve the documentation on data locality (#3127)
    + Improve the documentation on dealing with video (#3176)
    + Update broken link for Canny filter documentation (#3276)
    + Fix incorrect documentation for the center parameter of
    skimage.transform.rotate (#3341)
    + Fix incorrect formatting of docstring in measure.profile_line
    (#3236)
  * Build process / development
    + Ensure Cython is 0.23.4 or newer (#3171)
    + Suppress warnings during testing (#3143)
    + Fix skimage.test (#3152)
    + Don't upload artifacts to AppVeyor (there is no way to delete
    them) (#3315)
    + Remove import * from the scikit-image package root (#3265)
    + Allow named non-core contributors to issue MeeseeksDev commands
    (#3357, #3358)
    + Add testing in Python 3.7 (#3359)
    + Add license file to the binary distribution (#3322)
    + lookfor is no longer defined in __init__.py but rather imported
    to it (#3162)
    + Add pyproject.toml to ensure Cython is present before building
    (#3295)
    + Add explicit Python version Trove classifiers for PyPI (#3417)
    + Ignore known test failures in 32-bit releases, allowing 32-bit
    wheel builds (#3434)
    + Ignore failure to raise floating point warnings on certain ARM
    platforms (#3337)
    + Fix tests to be compatible with PyWavelets 1.0 (#3406)
* Sun Sep  2 2018 arun@gmx.de
- specfile:
  * update copyright year
  * TASKS file not in tar-ball anymore, removed it, added CONTRIBUTING.txt file
- update to version 0.14.0:
  * New Features
    + Lookfor function to search across the library:
    skimage.lookfor. (#2713)
    + nD support for skimage.transform.rescale,
    skimage.transform.resize, and skimage.transform.pyramid_*
    transforms. (#1522)
    + Chan-Vese segmentation algorithm. (#1957)
    + Manual segmentation with matplotlib for fast data annotation:
    skimage.future.manual_polygon_segmentation,
    skimage.future.manual_lasso_segmentation. (#2584)
    + Hysteresis thresholding:
    skimage.filters.apply_hysteresis_threshold. (#2665)
    + Segmentation with morphological snakes:
    skimage.segmentation.morphological_chan_vese (2D),
    skimage.segmentation.morphological_geodesic_active_contour (2D
    and 3D). (#2791)
    + nD support for image moments: skimage.measure.moments_central,
    skimage.measure.moments_central,
    skimage.measure.moments_normalized,
    skimage.measure.moments_hu. This change leads to 3D/nD
    compatibility for many regionprops. (#2603)
    + Image moments from coordinate input:
    skimage.measure.moments_coords,
    skimage.measure.moments_coords_central. (#2859)
    + Added 3D support to blob_dog and blob_log. (#2854)
    + Inertia tensor and its eigenvalues can now be computed outside
    of regionprops; available in
    skimage.measure.inertia_tensor. (#2603)
    + Cycle-spinning function for approximating shift-invariance by
    averaging results from a series of spatial shifts:
    skimage.restoration.cycle_spin. (#2647)
    + Haar-like feature: skimage.feature.haar_like_feature,
    skimage.feature.haar_like_feature_coord,
    skimage.feature.draw_haar_like_feature. (#2848)
    + Data generation with random_shapes function:
    skimage.draw.random_shapes. (#2773)
    + Subset of LFW (Labeled Faces in the Wild) database:
    skimage.data.cbcl_face_database. (#2905)
    + Fully reworked montage function (now with a better padding
    behavior): skimage.util.montage. (#2626)
    + YDbDr colorspace conversion routines: skimage.color.rgb2ydbdr,
    skimage.color.ydbdr2rgb. (#3018)
  * Improvements
    + VisuShrink method for
    skimage.restoration.denoise_wavelet. (#2470)
    + New max_ratio parameter for
    skimage.feature.match_descriptors. (#2472)
    + skimage.transform.resize and skimage.transform.rescale have a
    new anti_aliasing option to avoid aliasing artifacts when
    down-sampling images. (#2802)
    + Support for multichannel images for skimage.feature.hog. (#2870)
    + Non-local means denoising (skimage.restoration.denoise_nl_means)
    has a new optional parameter, sigma, that can be used to specify
    the noise standard deviation. This enables noise-robust patch
    distance estimation. (#2890)
    + Mixed dtypes support for skimage.measure.compare_ssim,
    skimage.measure.compare_psnr, etc. (#2893)
    + New alignment parameter in skimage.feature.plot_matches. (#2955)
    + New seed parameter in
    skimage.transform.probabilistic_hough_line. (#2960)
    + Various performance improvements. (#2821, #2878, #2967, #3035,
    [#3056], #3100)
  * Bugfixes
    + Fixed skimage.measure.regionprops.bbox_area returning incorrect
    value. (#2837)
    + Changed gradient and L2-Hys norm computation in
    skimage.feature.hog to closely follow the paper. (#2864)
    + Fixed skimage.color.convert_colorspace not working for YCbCr,
    YPbPr. (#2780)
    + Fixed incorrect composition of projective tranformation with
    inverse transformation. (#2826)
    + Fixed bug in random walker appearing when seed pixels are
    isolated inside pruned zones. (#2946)
    + Fixed rescale not working properly with different rescale
    factors in multichannel case. (#2959)
    + Fixed float and integer dtype support in
    skimage.util.invert. (#3030)
    + Fixed skimage.measure.find_contours raising StopIteration on
    Python 3.7. (#3038)
    + Fixed platform-specific issues appearing in Windows and/or
    32-bit environments. (#2867, #3033)
  * API Changes
    + skimage.util.montage. namespace has been removed, and
    skimage.util.montage.montage2d function is now available as
    skimage.util.montage2d.
    + skimage.morphology.binary_erosion now uses True as border value,
    and is now consistent with skimage.morphology.erosion.
  * Deprecations
    + freeimage plugin has been removed from skimage.io.
    + skimage.util.montage2d is deprecated and will be removed in
    0.15. Use skimage.util.montage function instead.
    + skimage.novice is deprecated and will be removed in 0.16.
    + skimage.transform.resize and skimage.transform.rescale have a
    new anti_aliasing option that avoids aliasing artifacts when
    down-sampling images. This option will be enabled by default in
    0.15.
    + regionprops will use row-column coordinates in 0.16. You can
    start using them now with regionprops(...,
    coordinates='rc'). You can silence warning messages, and retain
    the old behavior, with regionprops(...,
    coordinates='xy'). However, that option will go away in 0.16 and
    result in an error. This change has a number of
    consequences. Specifically, the "orientation" region property
    will measure the anticlockwise angle from a vertical line,
    i.e. from the vector (1, 0) in row-column coordinates.
    + skimage.morphology.remove_small_holes min_size argument is
    deprecated and will be removed in 0.16. Use area_threshold
    instead.
* Sat Sep 30 2017 arun@gmx.de
- update to version 0.13.1:
  * no upstream changelog available for 0.13.1
- 0.13.0 changelog available at: https://github.com/scikit-image/scikit-image/blob/master/doc/release/release_0.13.rst
* Mon Jun 12 2017 toddrme2178@gmail.com
- Implement single-spec version
- Update source URL
- Update to version 0.13.0
  * No upstream changelog
* Mon Jan 11 2016 toddrme2178@gmail.com
- update to version 0.11.3:
  (no changelog entry, taken from git log)
  * Fix handling of non-gif and tiff files
  * Fix setup to allow installing from PyPI
  * Fix support for Sphinx 1.3
  * Add a helper function to check for low contrast
  * Fix RANSAC for invalid model estimation and confidence corner case
- Fix update-alternatives usage
* Sat Nov 23 2013 p.drouand@gmail.com
- Missing 0.9.3 tarball in previous commit; upload it and remove old
  tarball
* Mon Oct 21 2013 toddrme2178@gmail.com
- Update to 0.9.3
  * No upstream changelog
- Rename to python-scikit-image to match new naming policy
* Sat Oct 13 2012 Angelos Tzotsos <tzotsos@opensuse.org>
- update version to 0.7.0
* Sun Mar 11 2012 Angelos Tzotsos <tzotsos@opensuse.org>
- initial OBS Build (v0.5.0)
